@@ -1,4 +1,4 @@
-`fixef.jointModel` <-
+fixef.jointModel <-
 function (object, process = c("Longitudinal", "Event"), include.splineCoefs = FALSE, ...) {
     if (!inherits(object, "jointModel"))
         stop("Use only with 'jointModel' objects.\n")
@@ -12,7 +12,10 @@ function (object, process = c("Longitudinal", "Event"), include.splineCoefs = FA
             nw <- ncol(object$x$W)
             gammas <- if (is.null(nw)) NULL else gammas[seq(ng - nw + 1, ng)]
         }
-        c(gammas, "Assoct" = as.vector(object$coefficients$alpha))
+        out <- c(gammas, "Assoct" = as.vector(object$coefficients$alpha))
+        if (object$method == "weibull-AFT-GH")
+            out <- - out
+        out
     }
 }
 
