@@ -1,4 +1,4 @@
-`opt.survCH` <-
+opt.survCH <-
 function (thetas) {
     gammas <- thetas[1:ncww]
     alpha <- thetas[ncww + 1]
